@@ -2,7 +2,7 @@
 Implementation of a (PyTorch) Dataset for benchmarks, also providing access methods
 via numpy arrays or pandas dataframes (should not access this class directly).
 """
-
+import pathlib
 import shutil
 from collections import defaultdict
 from functools import cached_property, partial
@@ -18,7 +18,7 @@ from requests import HTTPError
 from torch.utils.data import Dataset
 from tqdm.auto import tqdm
 
-from .utils import has_package_installed, PathLike
+from ..utils import has_package_installed, PathLike
 
 __all__ = [
     # functions
@@ -108,7 +108,10 @@ class DatasetFormatError(Exception):
 
 
 def validate_dataset_file(filepath: PathLike):
-    filepath = Path(filepath)
+    if not isinstance(filepath, pathlib.Path) and filepath.startswith('file://'):
+        filepath = filepath[7:]
+    else:
+        filepath = Path(filepath)
     
     # check file itself
     if not filepath.exists():
@@ -168,8 +171,14 @@ def validate_dataset_file(filepath: PathLike):
     num_outputs = []
     
     for split in splits_parts:
-        input_data = data[f'{split}-data']
-        output_data = data[f'{split}-labels']
+        try:
+            input_data = data[f'{split}-data']
+        except ValueError:
+            raise DatasetFormatError(f'Input array for `{split}` split requires pickle')
+        try:
+            output_data = data[f'{split}-labels']
+        except ValueError:
+            raise DatasetFormatError(f'Output array for `{split}` split requires pickle')
         
         if len(input_data.shape) != 2:
             raise DatasetFormatError('Dataset input data must be 2-dimensional')
@@ -325,7 +334,7 @@ class OpenTabularDataset(Dataset):
         return data[f'{split}-data'], data[f'{split}-labels']
 
     def __len__(self):
-        return self.input_attributes.shape[0]
+        return self.inputs.shape[0]
 
     def __getitem__(self, idx):
         inputs = self.inputs[idx, :]
@@ -342,7 +351,8 @@ class OpenTabularDataset(Dataset):
         if not isinstance(OpenTabularDataset, other):
             return False
         
-        return self.name == other.name and self.split == other.split and self.transform == other.transform
+        return self.name == other.name and self.split == other.split and self.transform == other.transform \
+            and self.target_transform == self.target_transform
     
     def __repr__(self):
         attributes = {
@@ -350,6 +360,7 @@ class OpenTabularDataset(Dataset):
             'name': repr(self.name),
             'split': repr(self.split),
             'transform': repr(self.transform),
+            'target_transform': repr(self.target_transform),
         }
         attributes_string = ', '.join(
                 '='.join(pair) for pair in attributes.items()
